Concepts
========

These documents explore the ideas behind Flask-Jeroboam: how it works, why it's designed the way it is, and what tradeoffs we've made.

.. toctree::
   :maxdepth: 1

   architecture
   design-philosophy
   pydantic-integration
